@@ -26,7 +26,6 @@ class KatDep(KatRes):
       'deploy'
     ]
 
-
   @property
   def pod_spec(self) -> V1PodSpec:
     return self.raw.spec.template.spec
@@ -47,6 +46,10 @@ class KatDep(KatRes):
   def ready_replicas(self):
     return self.raw.status.ready_replicas
 
+  @property
+  def replica_count(self):
+    return self.raw.status.replicas
+
   # --
   # --
   # --
@@ -56,15 +59,16 @@ class KatDep(KatRes):
   # --
 
   def ternary_status(self):
-    if self.is_running_normally():
-      return 'positive'
-    elif self.has_broken_pod():
-      return 'negative'
+    statuses = [p.ternary_status() for p in self.pods()]
+    if len(set(statuses)) == 1:
+      return statuses[0]
+    elif len(set(statuses)) > 1:
+      return 'negative' if 'negative' in statuses else 'pending'
     else:
       return 'pending'
 
   def is_running_normally(self):
-    return self.ready_replicas == self.desired_replicas
+    return self.ready_replicas == self.replica_count
 
   def has_broken_pod(self) -> bool:
     from k8kat.res.pod.kat_pod import KatPod
